/*
 * Copyright (C) 2015 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.2
import Qt.labs.settings 1.0

import Ubuntu.Components 1.1
import Ubuntu.Components.ListItems 1.0 as ListItem

Page {
    title: i18n.tr("Dialing")

    Flickable {
        anchors.fill: parent
        Column {
            anchors {
                left: parent.left
                right: parent.right
            }
            height: childrenRect.height

            ListItem.Standard {
                 text: i18n.tr("Format number before call")

                 control: CheckBox {
                     id: formatEnabledCheckBox

                     anchors.verticalCenter: parent.verticalCenter
                 }
             }

            ListItem.ValueSelector {
                id: operatorSelector

                enabled: dialingSettings.enabled
                text: i18n.tr("Operator")
                values: ["12 - Algar",
                         "14 - Oi",
                         "15 - Vivo",
                         "21 - Claro",
                         "23 - Intelig",
                         "25 - GVT",
                         "31 - Oi",
                         "41 - TIM"]
                onSelectedIndexChanged: dialingSettings.saveOperator()
            }
           ListItem.Standard {
                text: i18n.tr("Use operator for long distance calls")
                enabled: dialingSettings.enabled
                control: CheckBox {
                    id: useOperatorCheckBox

                    anchors.verticalCenter: parent.verticalCenter
                }
            }
            ListItem.Standard {
                text: i18n.tr("My state prefix")
                enabled: dialingSettings.enabled
                control: TextField {
                    id: myStatePredixField

                    anchors.verticalCenter: parent.verticalCenter
                    width: units.gu(10)
                }

            }
            ListItem.Standard {
                enabled: dialingSettings.enabled
                text: i18n.tr("Remove prefix for local calls")
                control: CheckBox {
                    id: removePrefixForLocalCallsCheckBox

                    anchors.verticalCenter: parent.verticalCenter
                }
            }
        }
    }

     Settings {
         id: dialingSettings

         category: "dialing-settings"
         property string operatorName
         property string operatorPrefix
         property alias enabled: formatEnabledCheckBox.checked
         property alias useOperatorInLongDistanceCalls: useOperatorCheckBox.checked
         property alias myStatePrefix: myStatePredixField.text
         property alias removePrefixForLocalCalls: removePrefixForLocalCallsCheckBox.checked


         function saveOperator()
         {
             if (operatorSelector.selectedIndex >= 0) {
                 var item = operatorSelector.values[operatorSelector.selectedIndex]
                 var itemSlices = item.split(' ')
                 operatorPrefix = itemSlices[0]
                 operatorName =  itemSlices[itemSlices.length - 1]
             }
         }

         function loadOperator()
         {
             for(var i in operatorSelector.values) {
                var item = operatorSelector.values[i]
                 if (item.indexOf(operatorName) !== -1) {
                     operatorSelector.selectedIndex = i
                     return
                 }
             }
         }
     }

     Component.onCompleted: dialingSettings.loadOperator()
}
